@@ -131,12 +131,14 @@ def test_typical_push(
     )
 
     # It should have invoked hook(s).
-    assert len(hookspy) == 24
+    assert len(hookspy) == 25
     (hook_name, hook_kwargs) = hookspy[0]
     assert hook_name == "task_start"
     (hook_name, hook_kwargs) = hookspy[1]
-    assert hook_name == "pulp_repository_pre_publish"
+    assert hook_name == "get_cert_key_paths"
     (hook_name, hook_kwargs) = hookspy[2]
+    assert hook_name == "pulp_repository_pre_publish"
+    (hook_name, hook_kwargs) = hookspy[3]
     assert hook_name == "pulp_repository_published"
     # after pulp_repository_published there's 13 calls of pulp_item_push_finished
     (hook_name, hook_kwargs) = hookspy[-15]
